about summary refs log tree commit diff
path: root/sysdeps/i386/elf
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/i386/elf')
-rw-r--r--sysdeps/i386/elf/start.S13
1 files changed, 7 insertions, 6 deletions
diff --git a/sysdeps/i386/elf/start.S b/sysdeps/i386/elf/start.S
index 868323b1b9..fb54066cc3 100644
--- a/sysdeps/i386/elf/start.S
+++ b/sysdeps/i386/elf/start.S
@@ -22,12 +22,12 @@
    point runs, most registers' values are unspecified, except for:
 
    %edx		Contains a function pointer to be registered with `atexit'.
-   		This is how the dynamic linker arranges to have DT_FINI
+		This is how the dynamic linker arranges to have DT_FINI
 		functions called for shared libraries that have been loaded
 		before this code runs.
 
    %esp		The stack contains the arguments and environment:
-   		0(%esp)			argc
+		0(%esp)			argc
 		4(%esp)			argv[0]
 		...
 		(4*argc)(%esp)		NULL
@@ -51,10 +51,11 @@ _start:
 	popl %esi		/* Pop the argument count.  */
 	movl %esp, %ecx		/* argv starts just at the current stack top.*/
 
-	/* Before pushing the arguments align the stack to a double word
-	   boundary to avoid penalties from misaligned accesses.  Thanks
-	   to Edward Seidl <seidl@janed.com> for pointing this out.  */
-	andl $0xfffffff8, %esp
+	/* Before pushing the arguments align the stack to a 16-byte
+	(SSE needs 16-byte alignment) boundary to avoid penalties from
+	misaligned accesses.  Thanks to Edward Seidl <seidl@janed.com>
+	for pointing this out.  */
+	andl $0xfffffff0, %esp
 	pushl %eax		/* Push garbage because we allocate
 				   28 more bytes.  */